@@ -40,6 +40,7 @@ static gboolean zenity_general_multiple;
 static gboolean zenity_general_editable;
 static gchar   *zenity_general_uri;
 static gboolean zenity_general_dialog_no_wrap;
+static guint    zenity_general_timeout_delay;
 
 /* Calendar Dialog Options */
 static gboolean zenity_calendar_active;
@@ -82,6 +83,7 @@ static gboolean zenity_progress_active;
 static int      zenity_progress_percentage;
 static gboolean zenity_progress_pulsate;
 static gboolean zenity_progress_auto_close;
+static gboolean zenity_progress_auto_kill;
 
 /* Question Dialog Options */
 static gboolean zenity_question_active;
@@ -142,6 +144,15 @@ static GOptionEntry general_options[] = {
     N_("Set the height"),
     N_("HEIGHT")
   },
+  {
+    "timeout",
+    '\0',
+    0,
+    G_OPTION_ARG_INT,
+    &zenity_general_timeout_delay,
+    N_("Set dialog timeout in seconds"),
+    NULL
+  },
   {
     NULL
   }
@@ -164,7 +175,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "day",
@@ -173,7 +184,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_INT,
     &zenity_calendar_day,
     N_("Set the calendar day"),
-    NULL
+    N_("DAY")
   },
   {
     "month",
@@ -182,7 +193,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_INT,
     &zenity_calendar_month,
     N_("Set the calendar month"),
-    NULL
+    N_("MONTH")
   },
   {
     "year",
@@ -191,7 +202,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_INT,
     &zenity_calendar_year,
     N_("Set the calendar year"),
-    NULL
+    N_("YEAR")
   },
   {
     "date-format",
@@ -200,7 +211,7 @@ static GOptionEntry calendar_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_calendar_date_format,
     N_("Set the format for the returned date"),
-    NULL
+    N_("PATTERN")
   },
   {
     NULL
@@ -221,10 +232,10 @@ static GOptionEntry entry_options[] = {
     "text",
     '\0',
     G_OPTION_FLAG_NOALIAS,
-    G_OPTION_ARG_STRING | G_OPTION_FLAG_NOALIAS,
+    G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "entry-text",
@@ -233,7 +244,7 @@ static GOptionEntry entry_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_entry_entry_text,
     N_("Set the entry text"),
-    NULL
+    N_("TEXT")
   },
   {
     "hide-text",
@@ -242,7 +253,7 @@ static GOptionEntry entry_options[] = {
     G_OPTION_ARG_NONE,
     &zenity_entry_hide_text,
     N_("Hide the entry text"),
-    NULL
+    N_("TEXT")
   },
   { 
     NULL 
@@ -267,7 +278,7 @@ static GOptionEntry error_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "no-wrap",
@@ -300,7 +311,7 @@ static GOptionEntry info_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "no-wrap",
@@ -402,7 +413,7 @@ static GOptionEntry list_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "column",
@@ -411,7 +422,7 @@ static GOptionEntry list_options[] = {
     G_OPTION_ARG_STRING_ARRAY,
     &zenity_list_columns,
     N_("Set the column header"),
-    NULL
+    N_("COLUMN")
   },
   {
     "checklist",
@@ -465,7 +476,8 @@ static GOptionEntry list_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_list_print_column,
     N_("Print a specific column (Default is 1. 'ALL' can be used to print all columns)"),
-    NULL
+    /* Column index number to print out on a list dialog */
+    N_("NUMBER")
   },
   {
     "hide-column",
@@ -474,7 +486,7 @@ static GOptionEntry list_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_list_hide_column,
     N_("Hide a specific column"),
-    NULL
+    N_("NUMBER")
   },
   { 
     NULL 
@@ -498,7 +510,7 @@ static GOptionEntry notification_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the notification text"),
-    NULL
+    N_("TEXT")
   },
   {
     "listen",
@@ -531,7 +543,7 @@ static GOptionEntry progress_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "percentage",
@@ -540,7 +552,7 @@ static GOptionEntry progress_options[] = {
     G_OPTION_ARG_INT,
     &zenity_progress_percentage,
     N_("Set initial percentage"),
-    NULL
+    N_("PERCENTAGE")
   },
   {
     "pulsate",
@@ -561,6 +573,16 @@ static GOptionEntry progress_options[] = {
     N_("Dismiss the dialog when 100% has been reached"),
     NULL
   },
+  {
+    "auto-kill",
+    '\0',
+    0,
+    G_OPTION_ARG_NONE,
+    &zenity_progress_auto_kill,
+    /* xgettext: no-c-format */
+    N_("Kill parent process if cancel button is pressed"),
+    NULL
+  },
   { 
     NULL 
   }
@@ -583,7 +605,7 @@ static GOptionEntry question_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "no-wrap",
@@ -649,7 +671,7 @@ static GOptionEntry warning_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "no-wrap",
@@ -682,7 +704,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_STRING,
     &zenity_general_dialog_text,
     N_("Set the dialog text"),
-    NULL
+    N_("TEXT")
   },
   {
     "value",
@@ -691,7 +713,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_INT,
     &zenity_scale_value,
     N_("Set initial value"),
-    NULL
+    N_("VALUE")
   },
   {
     "min-value",
@@ -700,7 +722,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_INT,
     &zenity_scale_min_value,
     N_("Set minimum value"),
-    NULL
+    N_("VALUE")
   },
   {
     "max-value",
@@ -709,7 +731,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_INT,
     &zenity_scale_max_value,
     N_("Set maximum value"),
-    NULL
+    N_("VALUE")
   },
   {
     "step",
@@ -718,7 +740,7 @@ static GOptionEntry scale_options[] = {
     G_OPTION_ARG_INT,
     &zenity_scale_step,
     N_("Set step size"),
-    NULL
+    N_("VALUE")
   },
   {
     "print-partial",
@@ -868,6 +890,7 @@ zenity_general_pre_callback (GOptionContext *context,
   zenity_general_editable = FALSE;
   zenity_general_uri = NULL;
   zenity_general_dialog_no_wrap = FALSE;
+  zenity_general_timeout_delay = -1;
 
   return TRUE;
 }
@@ -974,6 +997,7 @@ zenity_progress_pre_callback (GOptionContext *context,
   zenity_progress_percentage = 0;
   zenity_progress_pulsate = FALSE;
   zenity_progress_auto_close = FALSE;
+  zenity_progress_auto_kill = FALSE;
 
   return TRUE;
 }
@@ -1053,7 +1077,7 @@ zenity_general_post_callback (GOptionContext *context,
   results->data->window_icon = zenity_general_window_icon;
   results->data->width = zenity_general_width;
   results->data->height = zenity_general_height;
-
+  results->data->timeout_delay=zenity_general_timeout_delay;
   return TRUE;
 }
 
@@ -1282,6 +1306,7 @@ zenity_progress_post_callback (GOptionContext *context,
     results->progress_data->dialog_text = zenity_general_dialog_text;
     results->progress_data->pulsate = zenity_progress_pulsate;
     results->progress_data->autoclose = zenity_progress_auto_close;
+    results->progress_data->autokill = zenity_progress_auto_kill;
     results->progress_data->percentage = zenity_progress_percentage;
   } else {
     if (zenity_progress_pulsate)
@@ -1295,6 +1320,10 @@ zenity_progress_post_callback (GOptionContext *context,
     if (zenity_progress_auto_close)
       zenity_option_error (zenity_option_get_name (progress_options, &zenity_progress_auto_close),
                            ERROR_SUPPORT);
+                           
+    if (zenity_progress_auto_kill)
+      zenity_option_error (zenity_option_get_name (progress_options, &zenity_progress_auto_kill),
+                           ERROR_SUPPORT);
   }
     
   return TRUE;
@@ -1395,7 +1424,7 @@ zenity_create_context (void)
   /* Adds general option entries */
   a_group = g_option_group_new("general", 
                                N_("General options"), 
-                               N_("Show general options"), NULL, 0);
+                               N_("Show general options"), NULL, NULL);
   g_option_group_add_entries(a_group, general_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_general_pre_callback, zenity_general_post_callback);
@@ -1406,7 +1435,7 @@ zenity_create_context (void)
   /* Adds calendar option entries */
   a_group = g_option_group_new("calendar", 
                                N_("Calendar options"), 
-                               N_("Show calendar options"), NULL, 0);
+                               N_("Show calendar options"), NULL, NULL);
   g_option_group_add_entries(a_group, calendar_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_calendar_pre_callback, zenity_calendar_post_callback);
@@ -1417,7 +1446,7 @@ zenity_create_context (void)
   /* Adds entry option entries */
   a_group = g_option_group_new("entry", 
                                N_("Text entry options"), 
-                               N_("Show text entry options"), NULL, 0);
+                               N_("Show text entry options"), NULL, NULL);
   g_option_group_add_entries(a_group, entry_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_entry_pre_callback, zenity_entry_post_callback);
@@ -1428,7 +1457,7 @@ zenity_create_context (void)
   /* Adds error option entries */
   a_group = g_option_group_new("error", 
                                N_("Error options"), 
-                               N_("Show error options"), NULL, 0);
+                               N_("Show error options"), NULL, NULL);
   g_option_group_add_entries(a_group, error_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_error_pre_callback, zenity_error_post_callback);
@@ -1439,7 +1468,7 @@ zenity_create_context (void)
   /* Adds info option entries */
   a_group = g_option_group_new("info", 
                                N_("Info options"), 
-                               N_("Show info options"), NULL, 0);
+                               N_("Show info options"), NULL, NULL);
   g_option_group_add_entries(a_group, info_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_info_pre_callback, zenity_info_post_callback);
@@ -1450,7 +1479,7 @@ zenity_create_context (void)
   /* Adds file selection option entries */
   a_group = g_option_group_new("file-selection", 
                                N_("File selection options"), 
-                               N_("Show file selection options"), NULL, 0);
+                               N_("Show file selection options"), NULL, NULL);
   g_option_group_add_entries(a_group, file_selection_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_file_pre_callback, zenity_file_post_callback);
@@ -1461,7 +1490,7 @@ zenity_create_context (void)
   /* Adds list option entries */
   a_group = g_option_group_new("list", 
                                N_("List options"), 
-                               N_("Show list options"), NULL, 0);
+                               N_("Show list options"), NULL, NULL);
   g_option_group_add_entries(a_group, list_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_list_pre_callback, zenity_list_post_callback);
@@ -1472,7 +1501,7 @@ zenity_create_context (void)
   /* Adds notification option entries */
   a_group = g_option_group_new("notification", 
                                N_("Notification icon options"), 
-                               N_("Show notification icon options"), NULL, 0);
+                               N_("Show notification icon options"), NULL, NULL);
   g_option_group_add_entries(a_group, notification_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_notification_pre_callback, zenity_notification_post_callback);
@@ -1483,7 +1512,7 @@ zenity_create_context (void)
   /* Adds progress option entries */
   a_group = g_option_group_new("progress", 
                                N_("Progress options"), 
-                               N_("Show progress options"), NULL, 0);
+                               N_("Show progress options"), NULL, NULL);
   g_option_group_add_entries(a_group, progress_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_progress_pre_callback, zenity_progress_post_callback);
@@ -1494,7 +1523,7 @@ zenity_create_context (void)
   /* Adds question option entries */
   a_group = g_option_group_new("question", 
                                N_("Question options"), 
-                               N_("Show question options"), NULL, 0);
+                               N_("Show question options"), NULL, NULL);
   g_option_group_add_entries(a_group, question_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_question_pre_callback, zenity_question_post_callback);
@@ -1505,7 +1534,7 @@ zenity_create_context (void)
   /* Adds warning option entries */
   a_group = g_option_group_new("warning", 
                                N_("Warning options"), 
-                               N_("Show warning options"), NULL, 0);
+                               N_("Show warning options"), NULL, NULL);
   g_option_group_add_entries(a_group, warning_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_warning_pre_callback, zenity_warning_post_callback);
@@ -1516,7 +1545,7 @@ zenity_create_context (void)
   /* Adds scale option entries */
   a_group = g_option_group_new("scale", 
                                N_("Scale options"), 
-                               N_("Show scale options"), NULL, 0);
+                               N_("Show scale options"), NULL, NULL);
   g_option_group_add_entries(a_group, scale_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_scale_pre_callback, zenity_scale_post_callback);
@@ -1527,7 +1556,7 @@ zenity_create_context (void)
   /* Adds text option entries */
   a_group = g_option_group_new("text-info", 
                                N_("Text information options"), 
-                               N_("Show text information options"), NULL, 0);
+                               N_("Show text information options"), NULL, NULL);
   g_option_group_add_entries(a_group, text_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_text_pre_callback, zenity_text_post_callback);
@@ -1538,7 +1567,7 @@ zenity_create_context (void)
   /* Adds misc option entries */
   a_group = g_option_group_new("misc", 
                                N_("Miscellaneous options"), 
-                               N_("Show miscellaneous options"), NULL, 0);
+                               N_("Show miscellaneous options"), NULL, NULL);
   g_option_group_add_entries(a_group, miscellaneous_options);
   g_option_group_set_parse_hooks (a_group,
                     zenity_misc_pre_callback, zenity_misc_post_callback);
